@@ -31,6 +31,35 @@ def parse_args():
         default=False,
         help='output DEBUG logging statements (default: %(default)s)',
         )
+    parser.add_argument(
+        '-s',
+        '--script',
+        default='linkins-runnable',
+        type=str,
+        help=(
+            'Name of the script that can be executed at each level '
+            'of the target directory hierarchy. Scripts are never '
+            'linked (default: %(default)s)'
+            ),
+        )
+    parser.add_argument(
+        '-r',
+        '--run',
+        action='store_true',
+        default=False,
+        help=(
+            'Run the script (defined by --script) at each level of the '
+            'target directory hierarchy it is found (default: '
+            '%(default)s)'
+            ),
+        )
+    parser.add_argument(
+        '-p',
+        '--replace',
+        action='store_true',
+        default=False,
+        help='Replace existing links (default: %(default)s)',
+        )
     args = parser.parse_args()
     return args
 
@@ -45,7 +74,7 @@ def main():
     srcdir = util.abs_path(args.srcdir)
     linkdir = util.abs_path(args.linkdir)
     log.debug(
-        'Creating links from "{srcdir}" to "{linkdir}"'.format(
+        'Creating links from "{srcdir}" to "{linkdir}"...'.format(
             srcdir=srcdir,
             linkdir=linkdir,
         )
@@ -53,4 +82,7 @@ def main():
     link.make(
         srcdir=srcdir,
         linkdir=linkdir,
+        scriptname=args.script,
+        runscript=args.run,
+        replace=args.replace,
         )
